API docs for “spamfighter.interfaces.IMessageAnalyzer”

# Class s.i.IMessageAnalyzer(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Некоторый черный ящик анализа сообщений. Получает на вход сообщения и возвращает результат анализа.

Method | analyze | Анализировать входящие сообщение и вернуть результат анализа.

def analyze(message, domain): (source)
Анализировать входящие сообщение и вернуть результат анализа.

Parameters | message | анализируемое сообщение (type: `IMessage` )
| domain | текущий домен (type: `IDomain` )
Returns | результат анализа (type: `twisted.internet.defer.Deferred` )